===================================================
Telemeta : the open, social and audio audio CMS
===================================================

`Telemeta <http://telemeta.org>`_ is a web audio archiving program which introduces useful and secure methods to backup, index, transcode, analyse and publish any digitalized audio file with its metadata. It is dedicated to professionnals who wants to easily organize, backup and publish documented sound collections of audio files, CDs, digitalized vinyls and magnetic tapes over a strong database, in accordance with open web standards.

Key features of Telemeta:
    
 * Secure archiving, editing and publishing of audio files over internet.
 * User friendly web frontend including workflows and high level search methods
 * Smart dynamical and skinnable audio player (thanks to `TimeSide <http://code.google.com/p/timeside/>`_ and `SoundManager2 <http://www.schillmania.com/projects/soundmanager2/>`_)
 * "On the fly" analyzing, transcoding and metadata embedding based on an easy plugin architecture
 * Collaborative temporal indexing with fast user marker management
 * Multi-format support : FLAC, OGG, MP3, WAV and more
 * User management with individual profiles and rights
 * User playlist management with CSV data export
 * Geo-Navigator for audio geolocalization
 * `DublinCore <http://dublincore.org/>`_ compatibility
 * `OAI-PMH <http://www.openarchives.org/pmh/>`_ data provider
 * Relational database system (MySQL type)
 * RSS feeds generator
 * XML serialized backup

This web audio CMS is exclusively based on open source modules and can be run on any Unix or Linux system. It is mostly written in Python and JavaScript.

|

